<?php
/**
 * This file is part of PHPWord - A pure PHP library for reading and writing
 * word processing documents.
 *
 * PHPWord is free software distributed under the terms of the GNU Lesser
 * General Public License version 3 as published by the Free Software Foundation.
 *
 * For the full copyright and license information, please read the LICENSE
 * file that was distributed with this source code. For the full list of
 * contributors, visit https://github.com/PHPOffice/PHPWord/contributors.
 *
 * @link        https://github.com/PHPOffice/PHPWord
 * @copyright   2010-2014 PHPWord contributors
 * @license     http://www.gnu.org/licenses/lgpl.txt LGPL version 3
 */

namespace PhpOffice\PhpWord\Element;

use PhpOffice\PhpWord\Style\Paragraph;

/**
 * Textrun/paragraph element
 */
class TextRun extends AbstractContainer
{
    /**
     * @var string Container type
     */
    protected $container = 'TextRun';

    /**
     * Paragraph style
     *
     * @var string|\PhpOffice\PhpWord\Style\Paragraph
     */
    protected $paragraphStyle;

    /**
     * Create new instance
     *
     * @param string|array|\PhpOffice\PhpWord\Style\Paragraph $paragraphStyle
     */
    public function __construct($paragraphStyle = null)
    {
        global $comment;

        $this->paragraphStyle = $this->setNewStyle(new Paragraph(), $paragraphStyle);

        // Handle suggestion
        if (!is_array($paragraphStyle)) {
            //
        } elseif (array_key_exists('synocomment', $paragraphStyle) && array_key_exists('synosuggestion', $paragraphStyle)) {
            // count($comment) is used as revision ID
            // Push a fake annotation and set its type to 1 (suggestion) so that it will not be exported
            $comment[] = array('type' => 1);

            $c = $comment[$paragraphStyle['synocomment'][0]];
            $this->paragraphStyle->setRevision(array(
                'op' => array('deletion' => 'del', 'insertion' => 'ins')[$paragraphStyle['synosuggestion']],
                'id' => count($comment),
                'author' => $c['author'],
                'date' => $c['date']));
        } elseif (array_key_exists('revision', $paragraphStyle)) {
            $revision = $paragraphStyle['revision'];
            $this->paragraphStyle->setRevision($revision);
        }

        $this->addFloatingGraphs();
    }

    public function setParagraphStyle($paragraphStyle = null)
    {
        if ($paragraphStyle instanceof Paragraph) {
            $this->paragraphStyle = $paragraphStyle;
        } elseif (isset($this->paragraphStyle)) {
            $this->paragraphStyle->setStyleByArray($paragraphStyle);
        } else {
            $this->paragraphStyle = $this->setNewStyle(new Paragraph(), $paragraphStyle);
        }
    }

    /**
     * Get Paragraph style
     *
     * @return string|\PhpOffice\PhpWord\Style\Paragraph
     */
    public function getParagraphStyle()
    {
        return $this->paragraphStyle;
    }
}
