<?php
namespace PhpOffice\PhpWord\Element;

use PhpOffice\PhpWord\Style\Paragraph;

/**
 * Titlerun/paragraph element
 */
class TitleRun extends TextRun
{
    /**
     * @var string Container type
     */
    protected $container = 'TitleRun';

    /**
     * Paragraph style
     *
     * @var string|\PhpOffice\PhpWord\Style\Paragraph
     */
    protected $paragraphStyle;

    /**
     * Title depth
     *
     * @var int
     */
    private $depth = 1;

    /**
     * Create new instance
     *
     * @param string|array|\PhpOffice\PhpWord\Style\Paragraph $paragraphStyle
     * @param integer
     * @param \PhpOffice\PhpWord
     */
    public function __construct($paragraphStyle = null, $depth = 1, $relationId = null, $phpword = null)
    {
        parent::__construct($paragraphStyle);

        $this->setTitleDepth($depth);
        if (empty($relationId)) {
            $this->setRelationId($phpword->getTitles()->addItem($this));
        } else {
            $this->setRelationId($relationId);
        }
    }

    /**
     * Set heading level
     *
     * @param integer
     */
    public function setTitleDepth($depth)
    {
        $this->depth = $depth;
    }

    /**
     * Get Paragraph style
     *
     * @return string|\PhpOffice\PhpWord\Style\Paragraph
     */
    public function getParagraphStyle()
    {
        return $this->paragraphStyle;
    }

    /**
     * Get depth
     *
     * @return integer
     */
    public function getDepth()
    {
        return $this->depth;
    }

    /**
     * Get plain text in this TitleRun
     *
     * @return string
     */
    public function getText()
    {
        $text = '';
        foreach ($this->getElements() as $element) {
            if (method_exists($element, 'getText')) {
                $text .= $element->getText();
            }
        }
        return $text;
    }
}
