<?php
/**
 * This file is part of PHPWord - A pure PHP library for reading and writing
 * word processing documents.
 *
 * PHPWord is free software distributed under the terms of the GNU Lesser
 * General Public License version 3 as published by the Free Software Foundation.
 *
 * For the full copyright and license information, please read the LICENSE
 * file that was distributed with this source code. For the full list of
 * contributors, visit https://github.com/PHPOffice/PHPWord/contributors.
 *
 * @link        https://github.com/PHPOffice/PHPWord
 * @copyright   2010-2014 PHPWord contributors
 * @license     http://www.gnu.org/licenses/lgpl.txt LGPL version 3
 */

namespace PhpOffice\PhpWord\Writer\HTML_ProseMirror\Style;

/**
 * Paragraph style HTML writer
 *
 * @since 0.10.0
 */
class Paragraph extends AbstractStyle
{
    /**
     * Write style
     *
     * @return string
     */
    public function write()
    {
        $style = $this->getStyle()->getFinalStyle();
        if (!$style instanceof \PhpOffice\PhpWord\Style\Paragraph) {
            return '';
        }
        $css = array();

        // Alignment
        $align = $style->getAlign();
        $alignMap = array('end' => 'right', 'right' => 'right',
            'center' => 'center', 'both' => 'justify', 'distribute' => 'justify');
        if ( isset($alignMap[$align]) ) {
            $css['text-align'] = $alignMap[$align];
        } else if ( is_null($align) ) {
            $css['text-align'] = '';
        } else {
            $css['text-align'] = 'left';
        }

        // Spacing
        $spacing = $style->getSpace();
        if (!is_null($spacing)) {
            $before = $spacing->getBefore();
            $after = $spacing->getAfter();
            $css['margin-top'] = $this->getValueIf(!is_null($before), ($before / 20) . 'pt');
            $css['margin-bottom'] = $this->getValueIf(!is_null($after), ($after / 20) . 'pt');
        }

        // handle font related style
        $size = $style->getSize();
        if (!is_null($size)) {
            $css['font-size'] = $size . "pt";
        }
        $color = $style->getColor();
        if (!is_null($color)) {
            $css['color'] = "#" . $color;
        }

        // Indent
        $indent = $style->getIndent() - $style->getHanging();
        if (is_numeric($indent)) {
            $css['padding-left'] = $indent / 720 / 15 . "px";
        }

        return $this->assembleCss($css);
    }
}
