<?php
/**
 * This file is part of PHPWord - A pure PHP library for reading and writing
 * word processing documents.
 *
 * PHPWord is free software distributed under the terms of the GNU Lesser
 * General Public License version 3 as published by the Free Software Foundation.
 *
 * For the full copyright and license information, please read the LICENSE
 * file that was distributed with this source code. For the full list of
 * contributors, visit https://github.com/PHPOffice/PHPWord/contributors.
 *
 * @link        https://github.com/PHPOffice/PHPWord
 * @copyright   2010-2014 PHPWord contributors
 * @license     http://www.gnu.org/licenses/lgpl.txt LGPL version 3
 */

namespace PhpOffice\PhpWord\Writer\Word2007\Style;

use PhpOffice\PhpWord\Style\Frame as FrameStyle;
use PhpOffice\PhpWord\Style\Image as ImageStyle;

/**
 * Image style writer
 *
 * @since 0.10.0
 */
class Image extends Frame
{
    /**
     * Write style.
     *
     * @return void
     */
    public function write()
    {
        $style = $this->getStyle();
        if (!$style instanceof ImageStyle) {
            return;
        }
        $xmlWriter = $this->getXmlWriter();

        $zIndices = array(FrameStyle::WRAP_INFRONT => PHP_INT_MAX, FrameStyle::WRAP_BEHIND => -PHP_INT_MAX);

        $properties = array(
            'width'     => 'width',
            'height'    => 'height',
            'left'      => 'margin-left',
            'top'       => 'margin-top',
        );
        $sizeStyles = $this->getStyles($style, $properties, $style->getUnit());

        $properties = array(
            'pos'       => 'position',
            'hPos'      => 'mso-position-horizontal',
            'vPos'      => 'mso-position-vertical',
            'hPosRelTo' => 'mso-position-horizontal-relative',
            'vPosRelTo' => 'mso-position-vertical-relative',
        );
        $posStyles = $this->getStyles($style, $properties);

        $properties = array(
            'synoAlt'      => '-syno-alt',
            'synoFileId'   => '-syno-file-id',
            'synoFileType' => '-syno-file-type'
        );
        $synoStyles = $this->getStyles($style, $properties);

        $styles = array_merge($sizeStyles, $posStyles, $synoStyles);

        // zIndex for infront & behind wrap
        $wrap = $style->getWrap();
        if ($wrap !== null && isset($zIndices[$wrap])) {
            $styles['z-index'] = $zIndices[$wrap];
            $wrap = null;
        }

        // Style attribute
        $xmlWriter->writeAttribute('style', $this->assembleStyle($styles));

        $this->writeWrap($xmlWriter, $style, $wrap);
    }
}
